==> haskell-adjunctions-4.4.2-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 adjunctions
version:              4.4.2
visibility:           public
id:                   adjunctions-4.4.2-15bIPdZpLfBFeEAyb75tkK
key:                  adjunctions-4.4.2-15bIPdZpLfBFeEAyb75tkK
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/adjunctions/
synopsis:             Adjunctions and representable functors
description:          Adjunctions and representable functors.
category:             Data Structures, Adjunctions
abi:                  cce53c3a4365d5b5edf35ab8425b3dc1
exposed:              True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep

import-dirs:          /usr/lib/ghc-9.2.8/site-local/adjunctions-4.4.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/adjunctions-4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-adjunctions
hs-libraries:         HSadjunctions-4.4.2-15bIPdZpLfBFeEAyb75tkK
depends:
    array-0.5.4.0 base-4.16.4.0 comonad-5.0.8-FPX8fqTXWBRIN28hv9cMY3
    containers-0.6.5.1 contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
    distributive-0.6.2.1-83AMicm4Fuv4z0luD6O5UC
    free-5.1.10-G0zRLoFgcfkyw2MjpBSHA mtl-2.2.2
    profunctors-5.6.2-2RGdXGkx1Cq1Oei2KZIiCf
    semigroupoids-5.3.7-DRrQ6HM3i3lBidmriDf0rx
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    void-0.7.3-KUUN4OwBuM95y1GIrgJb5t

haddock-interfaces:   /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html:         /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-adjunctions-4.4.2-109-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 adjunctions
version:              4.4.2
visibility:           public
id:                   adjunctions-4.4.2-J6TeXmEqDpA25KuuvGaVOQ
key:                  adjunctions-4.4.2-J6TeXmEqDpA25KuuvGaVOQ
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/adjunctions/
synopsis:             Adjunctions and representable functors
description:          Adjunctions and representable functors.
category:             Data Structures, Adjunctions
abi:                  ccd29c5e784b990bc2712f5044549951
exposed:              True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep

import-dirs:          /usr/lib/ghc-9.2.8/site-local/adjunctions-4.4.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/adjunctions-4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-adjunctions
hs-libraries:         HSadjunctions-4.4.2-J6TeXmEqDpA25KuuvGaVOQ
depends:
    array-0.5.4.0 base-4.16.4.0 comonad-5.0.8-EltWStUOZ112UdaQVmuVnd
    containers-0.6.5.1 contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq
    distributive-0.6.2.1-9No2204dclP3UCFixPIren
    free-5.1.10-JYBndQTLyvuDhhk4wr5zld mtl-2.2.2
    profunctors-5.6.2-9I7OpCY8iRA9tnjQOVc7l5
    semigroupoids-5.3.7-CVlhZfzuWqLLDIZXfRThIz
    tagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    void-0.7.3-KUUN4OwBuM95y1GIrgJb5t

haddock-interfaces:   /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html:         /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
